@@ -243,14 +243,21 @@ class OpencorporaTag(object):
 
     _NUMERAL_AGREEMENT_GRAMMEMES = (
         set(['sing', 'nomn']),
+        set(['sing', 'accs']),
         set(['sing', 'gent']),
         set(['plur', 'nomn']),
         set(['plur', 'gent']),
     )
 
+    RARE_CASES = {
+        'gen2': 'gent',
+        'acc2': 'accs',
+        'loc2': 'loct',
+        'voct': 'nomn'
+    }
+
     def __init__(self, tag):
         self._str = tag
-
         # XXX: we loose information about which grammemes
         # belongs to lexeme and which belongs to form
         # (but this information seems useless for pymorphy2).
@@ -374,6 +381,13 @@ class OpencorporaTag(object):
             new_grammemes -= self._GRAMMEME_INCOMPATIBLE[grammeme]
         return new_grammemes
 
+    @classmethod
+    def fix_rare_cases(cls, grammemes):
+        """
+        Replace rare cases (loc2/voct/...) with common ones (loct/nomn/...).
+        """
+        return frozenset(cls.RARE_CASES.get(g,g) for g in grammemes)
+
     @classmethod
     def _init_grammemes(cls, dict_grammemes):
         """
@@ -433,21 +447,22 @@ class OpencorporaTag(object):
         if self.POS not in ('NOUN', 'ADJF', 'PRTF'):
             return set([])
 
-        if self.POS == 'NOUN' and self.case != 'nomn':
+        if self.POS == 'NOUN' and self.case not in ('nomn', 'accs'):
             if index == 0:
                 grammemes = set(['sing', self.case])
-            elif self.case == 'accs' and index == 2:
-                grammemes = self._NUMERAL_AGREEMENT_GRAMMEMES[3]
             else:
                 grammemes = set(['plur', self.case])
         elif index == 0:
-            grammemes = self._NUMERAL_AGREEMENT_GRAMMEMES[0]
+            if self.case == 'nomn':
+                grammemes = self._NUMERAL_AGREEMENT_GRAMMEMES[0]
+            else:
+                grammemes = self._NUMERAL_AGREEMENT_GRAMMEMES[1]
         elif self.POS == 'NOUN' and index == 1:
-            grammemes = self._NUMERAL_AGREEMENT_GRAMMEMES[1]
-        elif self.POS in ('ADJF', 'PRTF') and self.gender == 'femn' and index == 1:
             grammemes = self._NUMERAL_AGREEMENT_GRAMMEMES[2]
-        else:
+        elif self.POS in ('ADJF', 'PRTF') and self.gender == 'femn' and index == 1:
             grammemes = self._NUMERAL_AGREEMENT_GRAMMEMES[3]
+        else:
+            grammemes = self._NUMERAL_AGREEMENT_GRAMMEMES[4]
         return grammemes
 
 
